# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKThresholdingPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkHistogramThresholdImageFilterPython
else:
    import _itkHistogramThresholdImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkImagePython
import itk.itkVectorPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkCovariantVectorPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkPointPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrix_fixedPython
import itk.itkIndexPython
import itk.itkRGBAPixelPython
import itk.itkRGBPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkImageRegionPython
import itk.itkImageToImageFilterAPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageToImageFilterCommonPython
import itk.itkHistogramThresholdCalculatorPython
import itk.itkHistogramPython
import itk.itkArrayPython
import itk.itkSamplePython
import itk.itkSimpleDataObjectDecoratorPython
import itk.itkImageToHistogramFilterPython
import itk.itkImageSinkPython

def itkHistogramThresholdImageFilterIF2ISS2_New():
    return itkHistogramThresholdImageFilterIF2ISS2.New()

class itkHistogramThresholdImageFilterIF2ISS2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF2ISS2):
    r"""Proxy of C++ itkHistogramThresholdImageFilterIF2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramThresholdImageFilterIF2ISS2_Pointer"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramThresholdImageFilterIF2ISS2_Pointer"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2ISS2_Clone(self)

    def SetMaskImage(self, _arg):
        r"""
        SetMaskImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageSS2 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2ISS2_SetMaskImage(self, _arg)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageSS2"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2ISS2_GetMaskImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageF2 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2ISS2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageSS2 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2ISS2_SetInput2(self, input)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2ISS2_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> short"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2ISS2_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2ISS2_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> short"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2ISS2_GetInsideValue(self)

    def SetNumberOfHistogramBins(self, _arg):
        r"""
        SetNumberOfHistogramBins(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2ISS2_SetNumberOfHistogramBins(self, _arg)

    def GetNumberOfHistogramBins(self):
        r"""GetNumberOfHistogramBins(self) -> unsigned int"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2ISS2_GetNumberOfHistogramBins(self)

    def SetAutoMinimumMaximum(self, _arg):
        r"""
        SetAutoMinimumMaximum(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2ISS2_SetAutoMinimumMaximum(self, _arg)

    def GetAutoMinimumMaximum(self):
        r"""GetAutoMinimumMaximum(self) -> bool"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2ISS2_GetAutoMinimumMaximum(self)

    def AutoMinimumMaximumOn(self):
        r"""AutoMinimumMaximumOn(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2ISS2_AutoMinimumMaximumOn(self)

    def AutoMinimumMaximumOff(self):
        r"""AutoMinimumMaximumOff(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2ISS2_AutoMinimumMaximumOff(self)

    def SetMaskOutput(self, _arg):
        r"""
        SetMaskOutput(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2ISS2_SetMaskOutput(self, _arg)

    def GetMaskOutput(self):
        r"""GetMaskOutput(self) -> bool"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2ISS2_GetMaskOutput(self)

    def MaskOutputOn(self):
        r"""MaskOutputOn(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2ISS2_MaskOutputOn(self)

    def MaskOutputOff(self):
        r"""MaskOutputOff(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2ISS2_MaskOutputOff(self)

    def SetMaskValue(self, _arg):
        r"""
        SetMaskValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2ISS2_SetMaskValue(self, _arg)

    def GetMaskValue(self):
        r"""GetMaskValue(self) -> short"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2ISS2_GetMaskValue(self)

    def GetThreshold(self):
        r"""GetThreshold(self) -> float"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2ISS2_GetThreshold(self)

    def SetCalculator(self, _arg):
        r"""
        SetCalculator(self, _arg)

        Parameters
        ----------
        _arg: itkHistogramThresholdCalculatorHDF *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2ISS2_SetCalculator(self, _arg)

    def GetModifiableCalculator(self):
        r"""GetModifiableCalculator(self) -> itkHistogramThresholdCalculatorHDF"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2ISS2_GetModifiableCalculator(self)

    def GetCalculator(self, *args):
        r"""
        GetCalculator(self) -> itkHistogramThresholdCalculatorHDF
        GetCalculator(self) -> itkHistogramThresholdCalculatorHDF
        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2ISS2_GetCalculator(self, *args)
    OutputEqualityComparableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2ISS2_OutputEqualityComparableCheck
    
    InputOStreamWritableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2ISS2_InputOStreamWritableCheck
    
    OutputOStreamWritableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2ISS2_OutputOStreamWritableCheck
    
    __swig_destroy__ = _itkHistogramThresholdImageFilterPython.delete_itkHistogramThresholdImageFilterIF2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramThresholdImageFilterIF2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramThresholdImageFilterIF2ISS2

        Create a new object of the class itkHistogramThresholdImageFilterIF2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramThresholdImageFilterIF2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramThresholdImageFilterIF2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramThresholdImageFilterIF2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramThresholdImageFilterIF2ISS2 in _itkHistogramThresholdImageFilterPython:
_itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2ISS2_swigregister(itkHistogramThresholdImageFilterIF2ISS2)

def itkHistogramThresholdImageFilterIF2IUC2_New():
    return itkHistogramThresholdImageFilterIF2IUC2.New()

class itkHistogramThresholdImageFilterIF2IUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF2IUC2):
    r"""Proxy of C++ itkHistogramThresholdImageFilterIF2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramThresholdImageFilterIF2IUC2_Pointer"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramThresholdImageFilterIF2IUC2_Pointer"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2IUC2_Clone(self)

    def SetMaskImage(self, _arg):
        r"""
        SetMaskImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageUC2 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2IUC2_SetMaskImage(self, _arg)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageUC2"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2IUC2_GetMaskImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageF2 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2IUC2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2IUC2_SetInput2(self, input)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2IUC2_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> unsigned char"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2IUC2_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2IUC2_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> unsigned char"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2IUC2_GetInsideValue(self)

    def SetNumberOfHistogramBins(self, _arg):
        r"""
        SetNumberOfHistogramBins(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2IUC2_SetNumberOfHistogramBins(self, _arg)

    def GetNumberOfHistogramBins(self):
        r"""GetNumberOfHistogramBins(self) -> unsigned int"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2IUC2_GetNumberOfHistogramBins(self)

    def SetAutoMinimumMaximum(self, _arg):
        r"""
        SetAutoMinimumMaximum(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2IUC2_SetAutoMinimumMaximum(self, _arg)

    def GetAutoMinimumMaximum(self):
        r"""GetAutoMinimumMaximum(self) -> bool"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2IUC2_GetAutoMinimumMaximum(self)

    def AutoMinimumMaximumOn(self):
        r"""AutoMinimumMaximumOn(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2IUC2_AutoMinimumMaximumOn(self)

    def AutoMinimumMaximumOff(self):
        r"""AutoMinimumMaximumOff(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2IUC2_AutoMinimumMaximumOff(self)

    def SetMaskOutput(self, _arg):
        r"""
        SetMaskOutput(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2IUC2_SetMaskOutput(self, _arg)

    def GetMaskOutput(self):
        r"""GetMaskOutput(self) -> bool"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2IUC2_GetMaskOutput(self)

    def MaskOutputOn(self):
        r"""MaskOutputOn(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2IUC2_MaskOutputOn(self)

    def MaskOutputOff(self):
        r"""MaskOutputOff(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2IUC2_MaskOutputOff(self)

    def SetMaskValue(self, _arg):
        r"""
        SetMaskValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2IUC2_SetMaskValue(self, _arg)

    def GetMaskValue(self):
        r"""GetMaskValue(self) -> unsigned char"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2IUC2_GetMaskValue(self)

    def GetThreshold(self):
        r"""GetThreshold(self) -> float"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2IUC2_GetThreshold(self)

    def SetCalculator(self, _arg):
        r"""
        SetCalculator(self, _arg)

        Parameters
        ----------
        _arg: itkHistogramThresholdCalculatorHDF *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2IUC2_SetCalculator(self, _arg)

    def GetModifiableCalculator(self):
        r"""GetModifiableCalculator(self) -> itkHistogramThresholdCalculatorHDF"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2IUC2_GetModifiableCalculator(self)

    def GetCalculator(self, *args):
        r"""
        GetCalculator(self) -> itkHistogramThresholdCalculatorHDF
        GetCalculator(self) -> itkHistogramThresholdCalculatorHDF
        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2IUC2_GetCalculator(self, *args)
    OutputEqualityComparableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2IUC2_OutputEqualityComparableCheck
    
    InputOStreamWritableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2IUC2_InputOStreamWritableCheck
    
    OutputOStreamWritableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2IUC2_OutputOStreamWritableCheck
    
    __swig_destroy__ = _itkHistogramThresholdImageFilterPython.delete_itkHistogramThresholdImageFilterIF2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramThresholdImageFilterIF2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramThresholdImageFilterIF2IUC2

        Create a new object of the class itkHistogramThresholdImageFilterIF2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramThresholdImageFilterIF2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramThresholdImageFilterIF2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramThresholdImageFilterIF2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramThresholdImageFilterIF2IUC2 in _itkHistogramThresholdImageFilterPython:
_itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF2IUC2_swigregister(itkHistogramThresholdImageFilterIF2IUC2)

def itkHistogramThresholdImageFilterIF3ISS3_New():
    return itkHistogramThresholdImageFilterIF3ISS3.New()

class itkHistogramThresholdImageFilterIF3ISS3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF3ISS3):
    r"""Proxy of C++ itkHistogramThresholdImageFilterIF3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramThresholdImageFilterIF3ISS3_Pointer"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramThresholdImageFilterIF3ISS3_Pointer"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3ISS3_Clone(self)

    def SetMaskImage(self, _arg):
        r"""
        SetMaskImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageSS3 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3ISS3_SetMaskImage(self, _arg)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageSS3"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3ISS3_GetMaskImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageF3 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3ISS3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageSS3 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3ISS3_SetInput2(self, input)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3ISS3_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> short"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3ISS3_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3ISS3_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> short"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3ISS3_GetInsideValue(self)

    def SetNumberOfHistogramBins(self, _arg):
        r"""
        SetNumberOfHistogramBins(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3ISS3_SetNumberOfHistogramBins(self, _arg)

    def GetNumberOfHistogramBins(self):
        r"""GetNumberOfHistogramBins(self) -> unsigned int"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3ISS3_GetNumberOfHistogramBins(self)

    def SetAutoMinimumMaximum(self, _arg):
        r"""
        SetAutoMinimumMaximum(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3ISS3_SetAutoMinimumMaximum(self, _arg)

    def GetAutoMinimumMaximum(self):
        r"""GetAutoMinimumMaximum(self) -> bool"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3ISS3_GetAutoMinimumMaximum(self)

    def AutoMinimumMaximumOn(self):
        r"""AutoMinimumMaximumOn(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3ISS3_AutoMinimumMaximumOn(self)

    def AutoMinimumMaximumOff(self):
        r"""AutoMinimumMaximumOff(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3ISS3_AutoMinimumMaximumOff(self)

    def SetMaskOutput(self, _arg):
        r"""
        SetMaskOutput(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3ISS3_SetMaskOutput(self, _arg)

    def GetMaskOutput(self):
        r"""GetMaskOutput(self) -> bool"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3ISS3_GetMaskOutput(self)

    def MaskOutputOn(self):
        r"""MaskOutputOn(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3ISS3_MaskOutputOn(self)

    def MaskOutputOff(self):
        r"""MaskOutputOff(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3ISS3_MaskOutputOff(self)

    def SetMaskValue(self, _arg):
        r"""
        SetMaskValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3ISS3_SetMaskValue(self, _arg)

    def GetMaskValue(self):
        r"""GetMaskValue(self) -> short"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3ISS3_GetMaskValue(self)

    def GetThreshold(self):
        r"""GetThreshold(self) -> float"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3ISS3_GetThreshold(self)

    def SetCalculator(self, _arg):
        r"""
        SetCalculator(self, _arg)

        Parameters
        ----------
        _arg: itkHistogramThresholdCalculatorHDF *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3ISS3_SetCalculator(self, _arg)

    def GetModifiableCalculator(self):
        r"""GetModifiableCalculator(self) -> itkHistogramThresholdCalculatorHDF"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3ISS3_GetModifiableCalculator(self)

    def GetCalculator(self, *args):
        r"""
        GetCalculator(self) -> itkHistogramThresholdCalculatorHDF
        GetCalculator(self) -> itkHistogramThresholdCalculatorHDF
        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3ISS3_GetCalculator(self, *args)
    OutputEqualityComparableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3ISS3_OutputEqualityComparableCheck
    
    InputOStreamWritableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3ISS3_InputOStreamWritableCheck
    
    OutputOStreamWritableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3ISS3_OutputOStreamWritableCheck
    
    __swig_destroy__ = _itkHistogramThresholdImageFilterPython.delete_itkHistogramThresholdImageFilterIF3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramThresholdImageFilterIF3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramThresholdImageFilterIF3ISS3

        Create a new object of the class itkHistogramThresholdImageFilterIF3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramThresholdImageFilterIF3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramThresholdImageFilterIF3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramThresholdImageFilterIF3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramThresholdImageFilterIF3ISS3 in _itkHistogramThresholdImageFilterPython:
_itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3ISS3_swigregister(itkHistogramThresholdImageFilterIF3ISS3)

def itkHistogramThresholdImageFilterIF3IUC3_New():
    return itkHistogramThresholdImageFilterIF3IUC3.New()

class itkHistogramThresholdImageFilterIF3IUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF3IUC3):
    r"""Proxy of C++ itkHistogramThresholdImageFilterIF3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramThresholdImageFilterIF3IUC3_Pointer"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramThresholdImageFilterIF3IUC3_Pointer"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3IUC3_Clone(self)

    def SetMaskImage(self, _arg):
        r"""
        SetMaskImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageUC3 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3IUC3_SetMaskImage(self, _arg)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageUC3"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3IUC3_GetMaskImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageF3 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3IUC3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3IUC3_SetInput2(self, input)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3IUC3_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> unsigned char"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3IUC3_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3IUC3_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> unsigned char"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3IUC3_GetInsideValue(self)

    def SetNumberOfHistogramBins(self, _arg):
        r"""
        SetNumberOfHistogramBins(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3IUC3_SetNumberOfHistogramBins(self, _arg)

    def GetNumberOfHistogramBins(self):
        r"""GetNumberOfHistogramBins(self) -> unsigned int"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3IUC3_GetNumberOfHistogramBins(self)

    def SetAutoMinimumMaximum(self, _arg):
        r"""
        SetAutoMinimumMaximum(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3IUC3_SetAutoMinimumMaximum(self, _arg)

    def GetAutoMinimumMaximum(self):
        r"""GetAutoMinimumMaximum(self) -> bool"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3IUC3_GetAutoMinimumMaximum(self)

    def AutoMinimumMaximumOn(self):
        r"""AutoMinimumMaximumOn(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3IUC3_AutoMinimumMaximumOn(self)

    def AutoMinimumMaximumOff(self):
        r"""AutoMinimumMaximumOff(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3IUC3_AutoMinimumMaximumOff(self)

    def SetMaskOutput(self, _arg):
        r"""
        SetMaskOutput(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3IUC3_SetMaskOutput(self, _arg)

    def GetMaskOutput(self):
        r"""GetMaskOutput(self) -> bool"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3IUC3_GetMaskOutput(self)

    def MaskOutputOn(self):
        r"""MaskOutputOn(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3IUC3_MaskOutputOn(self)

    def MaskOutputOff(self):
        r"""MaskOutputOff(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3IUC3_MaskOutputOff(self)

    def SetMaskValue(self, _arg):
        r"""
        SetMaskValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3IUC3_SetMaskValue(self, _arg)

    def GetMaskValue(self):
        r"""GetMaskValue(self) -> unsigned char"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3IUC3_GetMaskValue(self)

    def GetThreshold(self):
        r"""GetThreshold(self) -> float"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3IUC3_GetThreshold(self)

    def SetCalculator(self, _arg):
        r"""
        SetCalculator(self, _arg)

        Parameters
        ----------
        _arg: itkHistogramThresholdCalculatorHDF *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3IUC3_SetCalculator(self, _arg)

    def GetModifiableCalculator(self):
        r"""GetModifiableCalculator(self) -> itkHistogramThresholdCalculatorHDF"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3IUC3_GetModifiableCalculator(self)

    def GetCalculator(self, *args):
        r"""
        GetCalculator(self) -> itkHistogramThresholdCalculatorHDF
        GetCalculator(self) -> itkHistogramThresholdCalculatorHDF
        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3IUC3_GetCalculator(self, *args)
    OutputEqualityComparableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3IUC3_OutputEqualityComparableCheck
    
    InputOStreamWritableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3IUC3_InputOStreamWritableCheck
    
    OutputOStreamWritableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3IUC3_OutputOStreamWritableCheck
    
    __swig_destroy__ = _itkHistogramThresholdImageFilterPython.delete_itkHistogramThresholdImageFilterIF3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramThresholdImageFilterIF3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramThresholdImageFilterIF3IUC3

        Create a new object of the class itkHistogramThresholdImageFilterIF3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramThresholdImageFilterIF3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramThresholdImageFilterIF3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramThresholdImageFilterIF3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramThresholdImageFilterIF3IUC3 in _itkHistogramThresholdImageFilterPython:
_itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIF3IUC3_swigregister(itkHistogramThresholdImageFilterIF3IUC3)

def itkHistogramThresholdImageFilterISS2ISS2_New():
    return itkHistogramThresholdImageFilterISS2ISS2.New()

class itkHistogramThresholdImageFilterISS2ISS2(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS2ISS2):
    r"""Proxy of C++ itkHistogramThresholdImageFilterISS2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramThresholdImageFilterISS2ISS2_Pointer"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramThresholdImageFilterISS2ISS2_Pointer"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2ISS2_Clone(self)

    def SetMaskImage(self, _arg):
        r"""
        SetMaskImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageSS2 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2ISS2_SetMaskImage(self, _arg)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageSS2"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2ISS2_GetMaskImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageSS2 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2ISS2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageSS2 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2ISS2_SetInput2(self, input)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2ISS2_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> short"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2ISS2_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2ISS2_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> short"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2ISS2_GetInsideValue(self)

    def SetNumberOfHistogramBins(self, _arg):
        r"""
        SetNumberOfHistogramBins(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2ISS2_SetNumberOfHistogramBins(self, _arg)

    def GetNumberOfHistogramBins(self):
        r"""GetNumberOfHistogramBins(self) -> unsigned int"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2ISS2_GetNumberOfHistogramBins(self)

    def SetAutoMinimumMaximum(self, _arg):
        r"""
        SetAutoMinimumMaximum(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2ISS2_SetAutoMinimumMaximum(self, _arg)

    def GetAutoMinimumMaximum(self):
        r"""GetAutoMinimumMaximum(self) -> bool"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2ISS2_GetAutoMinimumMaximum(self)

    def AutoMinimumMaximumOn(self):
        r"""AutoMinimumMaximumOn(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2ISS2_AutoMinimumMaximumOn(self)

    def AutoMinimumMaximumOff(self):
        r"""AutoMinimumMaximumOff(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2ISS2_AutoMinimumMaximumOff(self)

    def SetMaskOutput(self, _arg):
        r"""
        SetMaskOutput(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2ISS2_SetMaskOutput(self, _arg)

    def GetMaskOutput(self):
        r"""GetMaskOutput(self) -> bool"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2ISS2_GetMaskOutput(self)

    def MaskOutputOn(self):
        r"""MaskOutputOn(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2ISS2_MaskOutputOn(self)

    def MaskOutputOff(self):
        r"""MaskOutputOff(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2ISS2_MaskOutputOff(self)

    def SetMaskValue(self, _arg):
        r"""
        SetMaskValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2ISS2_SetMaskValue(self, _arg)

    def GetMaskValue(self):
        r"""GetMaskValue(self) -> short"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2ISS2_GetMaskValue(self)

    def GetThreshold(self):
        r"""GetThreshold(self) -> short"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2ISS2_GetThreshold(self)

    def SetCalculator(self, _arg):
        r"""
        SetCalculator(self, _arg)

        Parameters
        ----------
        _arg: itkHistogramThresholdCalculatorHDSS *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2ISS2_SetCalculator(self, _arg)

    def GetModifiableCalculator(self):
        r"""GetModifiableCalculator(self) -> itkHistogramThresholdCalculatorHDSS"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2ISS2_GetModifiableCalculator(self)

    def GetCalculator(self, *args):
        r"""
        GetCalculator(self) -> itkHistogramThresholdCalculatorHDSS
        GetCalculator(self) -> itkHistogramThresholdCalculatorHDSS
        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2ISS2_GetCalculator(self, *args)
    OutputEqualityComparableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2ISS2_OutputEqualityComparableCheck
    
    InputOStreamWritableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2ISS2_InputOStreamWritableCheck
    
    OutputOStreamWritableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2ISS2_OutputOStreamWritableCheck
    
    __swig_destroy__ = _itkHistogramThresholdImageFilterPython.delete_itkHistogramThresholdImageFilterISS2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramThresholdImageFilterISS2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramThresholdImageFilterISS2ISS2

        Create a new object of the class itkHistogramThresholdImageFilterISS2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramThresholdImageFilterISS2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramThresholdImageFilterISS2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramThresholdImageFilterISS2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramThresholdImageFilterISS2ISS2 in _itkHistogramThresholdImageFilterPython:
_itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2ISS2_swigregister(itkHistogramThresholdImageFilterISS2ISS2)

def itkHistogramThresholdImageFilterISS2IUC2_New():
    return itkHistogramThresholdImageFilterISS2IUC2.New()

class itkHistogramThresholdImageFilterISS2IUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS2IUC2):
    r"""Proxy of C++ itkHistogramThresholdImageFilterISS2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramThresholdImageFilterISS2IUC2_Pointer"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramThresholdImageFilterISS2IUC2_Pointer"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2IUC2_Clone(self)

    def SetMaskImage(self, _arg):
        r"""
        SetMaskImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageUC2 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2IUC2_SetMaskImage(self, _arg)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageUC2"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2IUC2_GetMaskImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageSS2 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2IUC2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2IUC2_SetInput2(self, input)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2IUC2_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> unsigned char"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2IUC2_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2IUC2_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> unsigned char"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2IUC2_GetInsideValue(self)

    def SetNumberOfHistogramBins(self, _arg):
        r"""
        SetNumberOfHistogramBins(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2IUC2_SetNumberOfHistogramBins(self, _arg)

    def GetNumberOfHistogramBins(self):
        r"""GetNumberOfHistogramBins(self) -> unsigned int"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2IUC2_GetNumberOfHistogramBins(self)

    def SetAutoMinimumMaximum(self, _arg):
        r"""
        SetAutoMinimumMaximum(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2IUC2_SetAutoMinimumMaximum(self, _arg)

    def GetAutoMinimumMaximum(self):
        r"""GetAutoMinimumMaximum(self) -> bool"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2IUC2_GetAutoMinimumMaximum(self)

    def AutoMinimumMaximumOn(self):
        r"""AutoMinimumMaximumOn(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2IUC2_AutoMinimumMaximumOn(self)

    def AutoMinimumMaximumOff(self):
        r"""AutoMinimumMaximumOff(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2IUC2_AutoMinimumMaximumOff(self)

    def SetMaskOutput(self, _arg):
        r"""
        SetMaskOutput(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2IUC2_SetMaskOutput(self, _arg)

    def GetMaskOutput(self):
        r"""GetMaskOutput(self) -> bool"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2IUC2_GetMaskOutput(self)

    def MaskOutputOn(self):
        r"""MaskOutputOn(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2IUC2_MaskOutputOn(self)

    def MaskOutputOff(self):
        r"""MaskOutputOff(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2IUC2_MaskOutputOff(self)

    def SetMaskValue(self, _arg):
        r"""
        SetMaskValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2IUC2_SetMaskValue(self, _arg)

    def GetMaskValue(self):
        r"""GetMaskValue(self) -> unsigned char"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2IUC2_GetMaskValue(self)

    def GetThreshold(self):
        r"""GetThreshold(self) -> short"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2IUC2_GetThreshold(self)

    def SetCalculator(self, _arg):
        r"""
        SetCalculator(self, _arg)

        Parameters
        ----------
        _arg: itkHistogramThresholdCalculatorHDSS *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2IUC2_SetCalculator(self, _arg)

    def GetModifiableCalculator(self):
        r"""GetModifiableCalculator(self) -> itkHistogramThresholdCalculatorHDSS"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2IUC2_GetModifiableCalculator(self)

    def GetCalculator(self, *args):
        r"""
        GetCalculator(self) -> itkHistogramThresholdCalculatorHDSS
        GetCalculator(self) -> itkHistogramThresholdCalculatorHDSS
        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2IUC2_GetCalculator(self, *args)
    OutputEqualityComparableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2IUC2_OutputEqualityComparableCheck
    
    InputOStreamWritableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2IUC2_InputOStreamWritableCheck
    
    OutputOStreamWritableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2IUC2_OutputOStreamWritableCheck
    
    __swig_destroy__ = _itkHistogramThresholdImageFilterPython.delete_itkHistogramThresholdImageFilterISS2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramThresholdImageFilterISS2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramThresholdImageFilterISS2IUC2

        Create a new object of the class itkHistogramThresholdImageFilterISS2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramThresholdImageFilterISS2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramThresholdImageFilterISS2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramThresholdImageFilterISS2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramThresholdImageFilterISS2IUC2 in _itkHistogramThresholdImageFilterPython:
_itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS2IUC2_swigregister(itkHistogramThresholdImageFilterISS2IUC2)

def itkHistogramThresholdImageFilterISS3ISS3_New():
    return itkHistogramThresholdImageFilterISS3ISS3.New()

class itkHistogramThresholdImageFilterISS3ISS3(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS3ISS3):
    r"""Proxy of C++ itkHistogramThresholdImageFilterISS3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramThresholdImageFilterISS3ISS3_Pointer"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramThresholdImageFilterISS3ISS3_Pointer"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3ISS3_Clone(self)

    def SetMaskImage(self, _arg):
        r"""
        SetMaskImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageSS3 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3ISS3_SetMaskImage(self, _arg)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageSS3"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3ISS3_GetMaskImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageSS3 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3ISS3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageSS3 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3ISS3_SetInput2(self, input)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3ISS3_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> short"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3ISS3_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3ISS3_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> short"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3ISS3_GetInsideValue(self)

    def SetNumberOfHistogramBins(self, _arg):
        r"""
        SetNumberOfHistogramBins(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3ISS3_SetNumberOfHistogramBins(self, _arg)

    def GetNumberOfHistogramBins(self):
        r"""GetNumberOfHistogramBins(self) -> unsigned int"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3ISS3_GetNumberOfHistogramBins(self)

    def SetAutoMinimumMaximum(self, _arg):
        r"""
        SetAutoMinimumMaximum(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3ISS3_SetAutoMinimumMaximum(self, _arg)

    def GetAutoMinimumMaximum(self):
        r"""GetAutoMinimumMaximum(self) -> bool"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3ISS3_GetAutoMinimumMaximum(self)

    def AutoMinimumMaximumOn(self):
        r"""AutoMinimumMaximumOn(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3ISS3_AutoMinimumMaximumOn(self)

    def AutoMinimumMaximumOff(self):
        r"""AutoMinimumMaximumOff(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3ISS3_AutoMinimumMaximumOff(self)

    def SetMaskOutput(self, _arg):
        r"""
        SetMaskOutput(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3ISS3_SetMaskOutput(self, _arg)

    def GetMaskOutput(self):
        r"""GetMaskOutput(self) -> bool"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3ISS3_GetMaskOutput(self)

    def MaskOutputOn(self):
        r"""MaskOutputOn(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3ISS3_MaskOutputOn(self)

    def MaskOutputOff(self):
        r"""MaskOutputOff(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3ISS3_MaskOutputOff(self)

    def SetMaskValue(self, _arg):
        r"""
        SetMaskValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3ISS3_SetMaskValue(self, _arg)

    def GetMaskValue(self):
        r"""GetMaskValue(self) -> short"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3ISS3_GetMaskValue(self)

    def GetThreshold(self):
        r"""GetThreshold(self) -> short"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3ISS3_GetThreshold(self)

    def SetCalculator(self, _arg):
        r"""
        SetCalculator(self, _arg)

        Parameters
        ----------
        _arg: itkHistogramThresholdCalculatorHDSS *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3ISS3_SetCalculator(self, _arg)

    def GetModifiableCalculator(self):
        r"""GetModifiableCalculator(self) -> itkHistogramThresholdCalculatorHDSS"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3ISS3_GetModifiableCalculator(self)

    def GetCalculator(self, *args):
        r"""
        GetCalculator(self) -> itkHistogramThresholdCalculatorHDSS
        GetCalculator(self) -> itkHistogramThresholdCalculatorHDSS
        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3ISS3_GetCalculator(self, *args)
    OutputEqualityComparableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3ISS3_OutputEqualityComparableCheck
    
    InputOStreamWritableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3ISS3_InputOStreamWritableCheck
    
    OutputOStreamWritableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3ISS3_OutputOStreamWritableCheck
    
    __swig_destroy__ = _itkHistogramThresholdImageFilterPython.delete_itkHistogramThresholdImageFilterISS3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramThresholdImageFilterISS3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramThresholdImageFilterISS3ISS3

        Create a new object of the class itkHistogramThresholdImageFilterISS3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramThresholdImageFilterISS3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramThresholdImageFilterISS3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramThresholdImageFilterISS3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramThresholdImageFilterISS3ISS3 in _itkHistogramThresholdImageFilterPython:
_itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3ISS3_swigregister(itkHistogramThresholdImageFilterISS3ISS3)

def itkHistogramThresholdImageFilterISS3IUC3_New():
    return itkHistogramThresholdImageFilterISS3IUC3.New()

class itkHistogramThresholdImageFilterISS3IUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS3IUC3):
    r"""Proxy of C++ itkHistogramThresholdImageFilterISS3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramThresholdImageFilterISS3IUC3_Pointer"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramThresholdImageFilterISS3IUC3_Pointer"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3IUC3_Clone(self)

    def SetMaskImage(self, _arg):
        r"""
        SetMaskImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageUC3 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3IUC3_SetMaskImage(self, _arg)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageUC3"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3IUC3_GetMaskImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageSS3 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3IUC3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3IUC3_SetInput2(self, input)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3IUC3_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> unsigned char"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3IUC3_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3IUC3_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> unsigned char"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3IUC3_GetInsideValue(self)

    def SetNumberOfHistogramBins(self, _arg):
        r"""
        SetNumberOfHistogramBins(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3IUC3_SetNumberOfHistogramBins(self, _arg)

    def GetNumberOfHistogramBins(self):
        r"""GetNumberOfHistogramBins(self) -> unsigned int"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3IUC3_GetNumberOfHistogramBins(self)

    def SetAutoMinimumMaximum(self, _arg):
        r"""
        SetAutoMinimumMaximum(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3IUC3_SetAutoMinimumMaximum(self, _arg)

    def GetAutoMinimumMaximum(self):
        r"""GetAutoMinimumMaximum(self) -> bool"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3IUC3_GetAutoMinimumMaximum(self)

    def AutoMinimumMaximumOn(self):
        r"""AutoMinimumMaximumOn(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3IUC3_AutoMinimumMaximumOn(self)

    def AutoMinimumMaximumOff(self):
        r"""AutoMinimumMaximumOff(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3IUC3_AutoMinimumMaximumOff(self)

    def SetMaskOutput(self, _arg):
        r"""
        SetMaskOutput(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3IUC3_SetMaskOutput(self, _arg)

    def GetMaskOutput(self):
        r"""GetMaskOutput(self) -> bool"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3IUC3_GetMaskOutput(self)

    def MaskOutputOn(self):
        r"""MaskOutputOn(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3IUC3_MaskOutputOn(self)

    def MaskOutputOff(self):
        r"""MaskOutputOff(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3IUC3_MaskOutputOff(self)

    def SetMaskValue(self, _arg):
        r"""
        SetMaskValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3IUC3_SetMaskValue(self, _arg)

    def GetMaskValue(self):
        r"""GetMaskValue(self) -> unsigned char"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3IUC3_GetMaskValue(self)

    def GetThreshold(self):
        r"""GetThreshold(self) -> short"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3IUC3_GetThreshold(self)

    def SetCalculator(self, _arg):
        r"""
        SetCalculator(self, _arg)

        Parameters
        ----------
        _arg: itkHistogramThresholdCalculatorHDSS *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3IUC3_SetCalculator(self, _arg)

    def GetModifiableCalculator(self):
        r"""GetModifiableCalculator(self) -> itkHistogramThresholdCalculatorHDSS"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3IUC3_GetModifiableCalculator(self)

    def GetCalculator(self, *args):
        r"""
        GetCalculator(self) -> itkHistogramThresholdCalculatorHDSS
        GetCalculator(self) -> itkHistogramThresholdCalculatorHDSS
        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3IUC3_GetCalculator(self, *args)
    OutputEqualityComparableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3IUC3_OutputEqualityComparableCheck
    
    InputOStreamWritableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3IUC3_InputOStreamWritableCheck
    
    OutputOStreamWritableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3IUC3_OutputOStreamWritableCheck
    
    __swig_destroy__ = _itkHistogramThresholdImageFilterPython.delete_itkHistogramThresholdImageFilterISS3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramThresholdImageFilterISS3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramThresholdImageFilterISS3IUC3

        Create a new object of the class itkHistogramThresholdImageFilterISS3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramThresholdImageFilterISS3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramThresholdImageFilterISS3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramThresholdImageFilterISS3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramThresholdImageFilterISS3IUC3 in _itkHistogramThresholdImageFilterPython:
_itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterISS3IUC3_swigregister(itkHistogramThresholdImageFilterISS3IUC3)

def itkHistogramThresholdImageFilterIUC2ISS2_New():
    return itkHistogramThresholdImageFilterIUC2ISS2.New()

class itkHistogramThresholdImageFilterIUC2ISS2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2ISS2):
    r"""Proxy of C++ itkHistogramThresholdImageFilterIUC2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramThresholdImageFilterIUC2ISS2_Pointer"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramThresholdImageFilterIUC2ISS2_Pointer"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2ISS2_Clone(self)

    def SetMaskImage(self, _arg):
        r"""
        SetMaskImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageSS2 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2ISS2_SetMaskImage(self, _arg)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageSS2"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2ISS2_GetMaskImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2ISS2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageSS2 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2ISS2_SetInput2(self, input)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2ISS2_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> short"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2ISS2_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2ISS2_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> short"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2ISS2_GetInsideValue(self)

    def SetNumberOfHistogramBins(self, _arg):
        r"""
        SetNumberOfHistogramBins(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2ISS2_SetNumberOfHistogramBins(self, _arg)

    def GetNumberOfHistogramBins(self):
        r"""GetNumberOfHistogramBins(self) -> unsigned int"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2ISS2_GetNumberOfHistogramBins(self)

    def SetAutoMinimumMaximum(self, _arg):
        r"""
        SetAutoMinimumMaximum(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2ISS2_SetAutoMinimumMaximum(self, _arg)

    def GetAutoMinimumMaximum(self):
        r"""GetAutoMinimumMaximum(self) -> bool"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2ISS2_GetAutoMinimumMaximum(self)

    def AutoMinimumMaximumOn(self):
        r"""AutoMinimumMaximumOn(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2ISS2_AutoMinimumMaximumOn(self)

    def AutoMinimumMaximumOff(self):
        r"""AutoMinimumMaximumOff(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2ISS2_AutoMinimumMaximumOff(self)

    def SetMaskOutput(self, _arg):
        r"""
        SetMaskOutput(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2ISS2_SetMaskOutput(self, _arg)

    def GetMaskOutput(self):
        r"""GetMaskOutput(self) -> bool"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2ISS2_GetMaskOutput(self)

    def MaskOutputOn(self):
        r"""MaskOutputOn(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2ISS2_MaskOutputOn(self)

    def MaskOutputOff(self):
        r"""MaskOutputOff(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2ISS2_MaskOutputOff(self)

    def SetMaskValue(self, _arg):
        r"""
        SetMaskValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2ISS2_SetMaskValue(self, _arg)

    def GetMaskValue(self):
        r"""GetMaskValue(self) -> short"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2ISS2_GetMaskValue(self)

    def GetThreshold(self):
        r"""GetThreshold(self) -> unsigned char"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2ISS2_GetThreshold(self)

    def SetCalculator(self, _arg):
        r"""
        SetCalculator(self, _arg)

        Parameters
        ----------
        _arg: itkHistogramThresholdCalculatorHDUC *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2ISS2_SetCalculator(self, _arg)

    def GetModifiableCalculator(self):
        r"""GetModifiableCalculator(self) -> itkHistogramThresholdCalculatorHDUC"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2ISS2_GetModifiableCalculator(self)

    def GetCalculator(self, *args):
        r"""
        GetCalculator(self) -> itkHistogramThresholdCalculatorHDUC
        GetCalculator(self) -> itkHistogramThresholdCalculatorHDUC
        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2ISS2_GetCalculator(self, *args)
    OutputEqualityComparableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2ISS2_OutputEqualityComparableCheck
    
    InputOStreamWritableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2ISS2_InputOStreamWritableCheck
    
    OutputOStreamWritableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2ISS2_OutputOStreamWritableCheck
    
    __swig_destroy__ = _itkHistogramThresholdImageFilterPython.delete_itkHistogramThresholdImageFilterIUC2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramThresholdImageFilterIUC2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramThresholdImageFilterIUC2ISS2

        Create a new object of the class itkHistogramThresholdImageFilterIUC2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramThresholdImageFilterIUC2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramThresholdImageFilterIUC2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramThresholdImageFilterIUC2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramThresholdImageFilterIUC2ISS2 in _itkHistogramThresholdImageFilterPython:
_itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2ISS2_swigregister(itkHistogramThresholdImageFilterIUC2ISS2)

def itkHistogramThresholdImageFilterIUC2IUC2_New():
    return itkHistogramThresholdImageFilterIUC2IUC2.New()

class itkHistogramThresholdImageFilterIUC2IUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2IUC2):
    r"""Proxy of C++ itkHistogramThresholdImageFilterIUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramThresholdImageFilterIUC2IUC2_Pointer"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramThresholdImageFilterIUC2IUC2_Pointer"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2IUC2_Clone(self)

    def SetMaskImage(self, _arg):
        r"""
        SetMaskImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageUC2 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2IUC2_SetMaskImage(self, _arg)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageUC2"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2IUC2_GetMaskImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2IUC2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2IUC2_SetInput2(self, input)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2IUC2_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> unsigned char"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2IUC2_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2IUC2_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> unsigned char"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2IUC2_GetInsideValue(self)

    def SetNumberOfHistogramBins(self, _arg):
        r"""
        SetNumberOfHistogramBins(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2IUC2_SetNumberOfHistogramBins(self, _arg)

    def GetNumberOfHistogramBins(self):
        r"""GetNumberOfHistogramBins(self) -> unsigned int"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2IUC2_GetNumberOfHistogramBins(self)

    def SetAutoMinimumMaximum(self, _arg):
        r"""
        SetAutoMinimumMaximum(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2IUC2_SetAutoMinimumMaximum(self, _arg)

    def GetAutoMinimumMaximum(self):
        r"""GetAutoMinimumMaximum(self) -> bool"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2IUC2_GetAutoMinimumMaximum(self)

    def AutoMinimumMaximumOn(self):
        r"""AutoMinimumMaximumOn(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2IUC2_AutoMinimumMaximumOn(self)

    def AutoMinimumMaximumOff(self):
        r"""AutoMinimumMaximumOff(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2IUC2_AutoMinimumMaximumOff(self)

    def SetMaskOutput(self, _arg):
        r"""
        SetMaskOutput(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2IUC2_SetMaskOutput(self, _arg)

    def GetMaskOutput(self):
        r"""GetMaskOutput(self) -> bool"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2IUC2_GetMaskOutput(self)

    def MaskOutputOn(self):
        r"""MaskOutputOn(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2IUC2_MaskOutputOn(self)

    def MaskOutputOff(self):
        r"""MaskOutputOff(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2IUC2_MaskOutputOff(self)

    def SetMaskValue(self, _arg):
        r"""
        SetMaskValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2IUC2_SetMaskValue(self, _arg)

    def GetMaskValue(self):
        r"""GetMaskValue(self) -> unsigned char"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2IUC2_GetMaskValue(self)

    def GetThreshold(self):
        r"""GetThreshold(self) -> unsigned char"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2IUC2_GetThreshold(self)

    def SetCalculator(self, _arg):
        r"""
        SetCalculator(self, _arg)

        Parameters
        ----------
        _arg: itkHistogramThresholdCalculatorHDUC *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2IUC2_SetCalculator(self, _arg)

    def GetModifiableCalculator(self):
        r"""GetModifiableCalculator(self) -> itkHistogramThresholdCalculatorHDUC"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2IUC2_GetModifiableCalculator(self)

    def GetCalculator(self, *args):
        r"""
        GetCalculator(self) -> itkHistogramThresholdCalculatorHDUC
        GetCalculator(self) -> itkHistogramThresholdCalculatorHDUC
        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2IUC2_GetCalculator(self, *args)
    OutputEqualityComparableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2IUC2_OutputEqualityComparableCheck
    
    InputOStreamWritableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2IUC2_InputOStreamWritableCheck
    
    OutputOStreamWritableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2IUC2_OutputOStreamWritableCheck
    
    __swig_destroy__ = _itkHistogramThresholdImageFilterPython.delete_itkHistogramThresholdImageFilterIUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramThresholdImageFilterIUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramThresholdImageFilterIUC2IUC2

        Create a new object of the class itkHistogramThresholdImageFilterIUC2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramThresholdImageFilterIUC2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramThresholdImageFilterIUC2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramThresholdImageFilterIUC2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramThresholdImageFilterIUC2IUC2 in _itkHistogramThresholdImageFilterPython:
_itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC2IUC2_swigregister(itkHistogramThresholdImageFilterIUC2IUC2)

def itkHistogramThresholdImageFilterIUC3ISS3_New():
    return itkHistogramThresholdImageFilterIUC3ISS3.New()

class itkHistogramThresholdImageFilterIUC3ISS3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3ISS3):
    r"""Proxy of C++ itkHistogramThresholdImageFilterIUC3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramThresholdImageFilterIUC3ISS3_Pointer"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramThresholdImageFilterIUC3ISS3_Pointer"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3ISS3_Clone(self)

    def SetMaskImage(self, _arg):
        r"""
        SetMaskImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageSS3 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3ISS3_SetMaskImage(self, _arg)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageSS3"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3ISS3_GetMaskImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3ISS3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageSS3 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3ISS3_SetInput2(self, input)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3ISS3_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> short"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3ISS3_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3ISS3_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> short"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3ISS3_GetInsideValue(self)

    def SetNumberOfHistogramBins(self, _arg):
        r"""
        SetNumberOfHistogramBins(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3ISS3_SetNumberOfHistogramBins(self, _arg)

    def GetNumberOfHistogramBins(self):
        r"""GetNumberOfHistogramBins(self) -> unsigned int"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3ISS3_GetNumberOfHistogramBins(self)

    def SetAutoMinimumMaximum(self, _arg):
        r"""
        SetAutoMinimumMaximum(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3ISS3_SetAutoMinimumMaximum(self, _arg)

    def GetAutoMinimumMaximum(self):
        r"""GetAutoMinimumMaximum(self) -> bool"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3ISS3_GetAutoMinimumMaximum(self)

    def AutoMinimumMaximumOn(self):
        r"""AutoMinimumMaximumOn(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3ISS3_AutoMinimumMaximumOn(self)

    def AutoMinimumMaximumOff(self):
        r"""AutoMinimumMaximumOff(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3ISS3_AutoMinimumMaximumOff(self)

    def SetMaskOutput(self, _arg):
        r"""
        SetMaskOutput(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3ISS3_SetMaskOutput(self, _arg)

    def GetMaskOutput(self):
        r"""GetMaskOutput(self) -> bool"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3ISS3_GetMaskOutput(self)

    def MaskOutputOn(self):
        r"""MaskOutputOn(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3ISS3_MaskOutputOn(self)

    def MaskOutputOff(self):
        r"""MaskOutputOff(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3ISS3_MaskOutputOff(self)

    def SetMaskValue(self, _arg):
        r"""
        SetMaskValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3ISS3_SetMaskValue(self, _arg)

    def GetMaskValue(self):
        r"""GetMaskValue(self) -> short"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3ISS3_GetMaskValue(self)

    def GetThreshold(self):
        r"""GetThreshold(self) -> unsigned char"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3ISS3_GetThreshold(self)

    def SetCalculator(self, _arg):
        r"""
        SetCalculator(self, _arg)

        Parameters
        ----------
        _arg: itkHistogramThresholdCalculatorHDUC *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3ISS3_SetCalculator(self, _arg)

    def GetModifiableCalculator(self):
        r"""GetModifiableCalculator(self) -> itkHistogramThresholdCalculatorHDUC"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3ISS3_GetModifiableCalculator(self)

    def GetCalculator(self, *args):
        r"""
        GetCalculator(self) -> itkHistogramThresholdCalculatorHDUC
        GetCalculator(self) -> itkHistogramThresholdCalculatorHDUC
        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3ISS3_GetCalculator(self, *args)
    OutputEqualityComparableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3ISS3_OutputEqualityComparableCheck
    
    InputOStreamWritableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3ISS3_InputOStreamWritableCheck
    
    OutputOStreamWritableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3ISS3_OutputOStreamWritableCheck
    
    __swig_destroy__ = _itkHistogramThresholdImageFilterPython.delete_itkHistogramThresholdImageFilterIUC3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramThresholdImageFilterIUC3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramThresholdImageFilterIUC3ISS3

        Create a new object of the class itkHistogramThresholdImageFilterIUC3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramThresholdImageFilterIUC3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramThresholdImageFilterIUC3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramThresholdImageFilterIUC3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramThresholdImageFilterIUC3ISS3 in _itkHistogramThresholdImageFilterPython:
_itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3ISS3_swigregister(itkHistogramThresholdImageFilterIUC3ISS3)

def itkHistogramThresholdImageFilterIUC3IUC3_New():
    return itkHistogramThresholdImageFilterIUC3IUC3.New()

class itkHistogramThresholdImageFilterIUC3IUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3IUC3):
    r"""Proxy of C++ itkHistogramThresholdImageFilterIUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramThresholdImageFilterIUC3IUC3_Pointer"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramThresholdImageFilterIUC3IUC3_Pointer"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3IUC3_Clone(self)

    def SetMaskImage(self, _arg):
        r"""
        SetMaskImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageUC3 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3IUC3_SetMaskImage(self, _arg)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageUC3"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3IUC3_GetMaskImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3IUC3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3IUC3_SetInput2(self, input)

    def SetOutsideValue(self, _arg):
        r"""
        SetOutsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3IUC3_SetOutsideValue(self, _arg)

    def GetOutsideValue(self):
        r"""GetOutsideValue(self) -> unsigned char"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3IUC3_GetOutsideValue(self)

    def SetInsideValue(self, _arg):
        r"""
        SetInsideValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3IUC3_SetInsideValue(self, _arg)

    def GetInsideValue(self):
        r"""GetInsideValue(self) -> unsigned char"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3IUC3_GetInsideValue(self)

    def SetNumberOfHistogramBins(self, _arg):
        r"""
        SetNumberOfHistogramBins(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3IUC3_SetNumberOfHistogramBins(self, _arg)

    def GetNumberOfHistogramBins(self):
        r"""GetNumberOfHistogramBins(self) -> unsigned int"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3IUC3_GetNumberOfHistogramBins(self)

    def SetAutoMinimumMaximum(self, _arg):
        r"""
        SetAutoMinimumMaximum(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3IUC3_SetAutoMinimumMaximum(self, _arg)

    def GetAutoMinimumMaximum(self):
        r"""GetAutoMinimumMaximum(self) -> bool"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3IUC3_GetAutoMinimumMaximum(self)

    def AutoMinimumMaximumOn(self):
        r"""AutoMinimumMaximumOn(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3IUC3_AutoMinimumMaximumOn(self)

    def AutoMinimumMaximumOff(self):
        r"""AutoMinimumMaximumOff(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3IUC3_AutoMinimumMaximumOff(self)

    def SetMaskOutput(self, _arg):
        r"""
        SetMaskOutput(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3IUC3_SetMaskOutput(self, _arg)

    def GetMaskOutput(self):
        r"""GetMaskOutput(self) -> bool"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3IUC3_GetMaskOutput(self)

    def MaskOutputOn(self):
        r"""MaskOutputOn(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3IUC3_MaskOutputOn(self)

    def MaskOutputOff(self):
        r"""MaskOutputOff(self)"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3IUC3_MaskOutputOff(self)

    def SetMaskValue(self, _arg):
        r"""
        SetMaskValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3IUC3_SetMaskValue(self, _arg)

    def GetMaskValue(self):
        r"""GetMaskValue(self) -> unsigned char"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3IUC3_GetMaskValue(self)

    def GetThreshold(self):
        r"""GetThreshold(self) -> unsigned char"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3IUC3_GetThreshold(self)

    def SetCalculator(self, _arg):
        r"""
        SetCalculator(self, _arg)

        Parameters
        ----------
        _arg: itkHistogramThresholdCalculatorHDUC *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3IUC3_SetCalculator(self, _arg)

    def GetModifiableCalculator(self):
        r"""GetModifiableCalculator(self) -> itkHistogramThresholdCalculatorHDUC"""
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3IUC3_GetModifiableCalculator(self)

    def GetCalculator(self, *args):
        r"""
        GetCalculator(self) -> itkHistogramThresholdCalculatorHDUC
        GetCalculator(self) -> itkHistogramThresholdCalculatorHDUC
        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3IUC3_GetCalculator(self, *args)
    OutputEqualityComparableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3IUC3_OutputEqualityComparableCheck
    
    InputOStreamWritableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3IUC3_InputOStreamWritableCheck
    
    OutputOStreamWritableCheck = _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3IUC3_OutputOStreamWritableCheck
    
    __swig_destroy__ = _itkHistogramThresholdImageFilterPython.delete_itkHistogramThresholdImageFilterIUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramThresholdImageFilterIUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramThresholdImageFilterIUC3IUC3

        Create a new object of the class itkHistogramThresholdImageFilterIUC3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramThresholdImageFilterIUC3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramThresholdImageFilterIUC3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramThresholdImageFilterIUC3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramThresholdImageFilterIUC3IUC3 in _itkHistogramThresholdImageFilterPython:
_itkHistogramThresholdImageFilterPython.itkHistogramThresholdImageFilterIUC3IUC3_swigregister(itkHistogramThresholdImageFilterIUC3IUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def histogram_threshold_image_filter(*args: itkt.ImageLike,  mask_image: itkt.Image=..., outside_value: int=..., inside_value: int=..., number_of_histogram_bins: int=..., auto_minimum_maximum: bool=..., mask_output: bool=..., mask_value: int=..., calculator=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for HistogramThresholdImageFilter"""
    import itk

    kwarg_typehints = { 'mask_image':mask_image,'outside_value':outside_value,'inside_value':inside_value,'number_of_histogram_bins':number_of_histogram_bins,'auto_minimum_maximum':auto_minimum_maximum,'mask_output':mask_output,'mask_value':mask_value,'calculator':calculator }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.HistogramThresholdImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def histogram_threshold_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKThresholding.HistogramThresholdImageFilter
    histogram_threshold_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    histogram_threshold_image_filter.__doc__ = filter_object.__doc__



